@@ -1,5 +1,8 @@
 from typing import Coroutine
 import asyncio
+import nest_asyncio
+from .. import settings
+
 
 def __ensure_event_loop():
     try:
@@ -11,7 +14,7 @@ def __ensure_event_loop():
 
 def sync(coroutine: Coroutine):
     """
-    同步执行异步函数，使用可参考 [同步执行异步代码](https://nemo2011.github.io/bilibili-api-docs/#/sync-executor)
+    同步执行异步函数，使用可参考 [同步执行异步代码](https://nemo2011.github.io/bilibili-api/#/sync-executor)
 
     Args:
         coroutine (Coroutine): 异步函数
@@ -19,7 +22,8 @@ def sync(coroutine: Coroutine):
     Returns:
         该异步函数的返回值
     """
+    if settings.nest_asyncio == True:
+        nest_asyncio.apply()
     __ensure_event_loop()
     loop = asyncio.get_event_loop()
     return loop.run_until_complete(coroutine)
-
